/*
 * Copyright 2019 Regents of the University of Minnesota.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package edu.umn.biomedicus.tagging.tnt;

import edu.umn.biomedicus.common.tuples.WordCap;

import java.util.function.UnaryOperator;

/**
 *
 */
public class WordCapAdapter implements UnaryOperator<WordCap> {

  private boolean toLowercase = false;

  private boolean ignoreCapitalization = false;

  public WordCapAdapter() {

  }

  public WordCapAdapter(boolean toLowercase, boolean ignoreCapitalization) {
    this.toLowercase = toLowercase;
    this.ignoreCapitalization = ignoreCapitalization;
  }

  @Override
  public WordCap apply(WordCap wordCap) {
    String word = wordCap.getWord();
    boolean isCapitalized = wordCap.isCapitalized();
    if (toLowercase) {
      word = word.toLowerCase();
    }
    if (ignoreCapitalization) {
      isCapitalized = false;
    }
    return new WordCap(word, isCapitalized);
  }

  public boolean isToLowercase() {
    return toLowercase;
  }

  public void setToLowercase(boolean toLowercase) {
    this.toLowercase = toLowercase;
  }

  public boolean isIgnoreCapitalization() {
    return ignoreCapitalization;
  }

  public void setIgnoreCapitalization(boolean ignoreCapitalization) {
    this.ignoreCapitalization = ignoreCapitalization;
  }
}
